Uses numerical differentiation via numDeriv::grad when analytic derivatives are not available for a specific HRF type.
Uses the analytic derivative formula for the SPM canonical HRF.
Returns derivatives for both the canonical HRF and its temporal derivative. The first column contains the derivative of the canonical HRF, and the second column contains the second derivative (derivative of the temporal derivative).
Returns derivatives for the canonical HRF and its two derivatives. Since SPMG3 already includes first and second derivatives as basis functions, this method returns their derivatives (1st, 2nd, and 3rd derivatives of the original HRF).